@@ -126,6 +126,8 @@ class KerberosCredential(UniCredential):
 		elif self.subprotocol.type == asyauthSubProtocol.WSNET:
 			from asyauth.protocols.kerberos.client.wsnet import KerberosClientWSNET
 			return KerberosClientWSNET(self)
+		elif self.subprotocol.type == asyauthSubProtocol.CUSTOM:
+			return self.subprotocol.factoryobj.build_context(self)
 		else:
 			raise Exception('Unsupported subprotocol "%s"' % self.subprotocol)
 
